@@ -30,6 +30,26 @@ createNaEstimate <- function(type) {
   return(estimate)
 }
 
+computePredictionInterval <- function(traces, alpha = 0.05) {
+  qmixnorm <- function(p, means, sds) {
+    pmix <- function(x) {
+      mean(pnorm(x, mean = means, sd = sds))
+    }
+    sapply(p, function(pVal) {
+      if (pVal <= 0) return(-Inf)
+      if (pVal >= 1) return(Inf)
+      objective_function <- function(x) {
+        pmix(x) - pVal
+      }
+      search_interval <- c(min(means) - 10 * max(sds), max(means) + 10 * max(sds))
+      uniroot(objective_function, interval = search_interval)$root
+    })
+  }
+
+  predictionInterval <- HDInterval::hdi(qmixnorm, credMass = 1 - alpha, means = traces[, 1], sds = traces[, 2])
+  return(predictionInterval)
+}
+
 #' Compute a Bayesian random-effects meta-analysis
 #'
 #' @description
@@ -68,11 +88,12 @@ createNaEstimate <- function(type) {
 #'     modelType = "cox"
 #'   )
 #'   cyclopsFit <- Cyclops::fitCyclopsModel(cyclopsData)
-#'   approximation <- approximateLikelihood(cyclopsFit, parameter = "x", approximation = "custom")
+#'   approximation <- approximateLikelihood(cyclopsFit,
+#'                                          parameter = "x",
+#'                                          approximation = "grid with gradients")
 #'   return(approximation)
 #' }
 #' approximations <- lapply(populations, fitModelInDatabase)
-#' approximations <- do.call("rbind", approximations)
 #'
 #' # At study coordinating center, perform meta-analysis using per-site approximations:
 #' estimate <- computeBayesianMetaAnalysis(approximations)
@@ -191,6 +212,15 @@ computeBayesianMetaAnalysis <- function(data,
     seLogRr = sqrt(mean((traces[, 1] - mu)^2)),
     row.names = NULL
   )
+  if (!robust) {
+    predictionInterval <- computePredictionInterval(traces, alpha)
+    estimate <- estimate |>
+      mutate(
+        predictionInterval95Lb = predictionInterval[1],
+        predictionInterval95Ub = predictionInterval[2]
+      )
+  }
+
   attr(estimate, "traces") <- traces
   attr(estimate, "type") <- type
   attr(estimate, "ess") <- coda::effectiveSize(traces)
