@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2023 Observational Health Data Sciences and Informatics
+ * Copyright 2025 Observational Health Data Sciences and Informatics
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -77,16 +77,14 @@ public class ExtendingEmpiricalDataModel extends EmpiricalDataModel {
 				//				}
 			}
 
-			public final double sqr(double x) {
-				return x * x;
-			}
-
 			@Override
 			public double gradientLogPdf(double x, EmpiricalDistributionData data) {
-				final int end = data.values.length;
+				final int end = data.values.length - 1;
 
-				if (x <= data.values[0] || x >= data.values[end]) {
-					return 0.0;
+				if (x <= data.values[0]) {
+					return Math.max(0, (data.density[1] - data.density[0]) / (data.values[1] - data.values[0]));
+				} else if (x >= data.values[end]) {
+					return Math.min(0, (data.density[end] - data.density[end - 1]) / (data.values[end] - data.values[end - 1]));
 				} else {
 					return super.gradientLogPdf(x, data);
 				}
