@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright 2023 Observational Health Data Sciences and Informatics
+ * Copyright 2025 Observational Health Data Sciences and Informatics
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,6 +38,6 @@ public class GammaOnPrecisionPrior extends Base implements ScalePrior {
 	@Override
 	public MCMCOperator getOperator(DistributionLikelihood hierarchicalLikelihood, double weight, AdaptationMode mode) {
 		return new NormalGammaPrecisionGibbsOperator(new GammaGibbsProvider.Default(hierarchicalLikelihood),
-				tauPrior.getDistribution(), null, weight);
+				new NormalGammaPrecisionGibbsOperator.GammaParametrization(tauPrior.getDistribution()), null, weight);
 	}
 }
